// BarcodeDLLImport.cs : A wrap class around the Barcode DLL exports
//
// This file is part of the Morovia Barcode DLL package.
// (c)2006, 2021 Morovia Corporation. All rights reserved.
//
// THIS SOURCE FILE IS THE PROPERTY OF MOROVIA CORPORATION AND IS NOT TO 
// BE RE-DISTRIBUTED BY ANY MEANS WHATSOEVER WITHOUT THE EXPRESSED 
// WRITTEN CONSENT OF MOROVIA.
//
// THIS SOURCE CODE CAN ONLY BE USED UNDER THE TERMS AND CONDITIONS 
// OUTLINED IN THE MOROVIA BARCODE COMPONENT LICENSE AGREEMENT.  MOROVIA 
// GRANTS TO YOU (ONE SOFTWARE DEVELOPER) THE LIMITED RIGHT TO USE 
// THIS SOFTWARE ON A SINGLE COMPUTER.
//
// MOROVIA EXPRESSLY DISCLAIMS ANY WARRANTY FOR THE SOFTWARE, DOCUMENTATION
// AND ANYTHING ELSE PROVIDED BY MOROVIA HEREBY AND MOROVIA PROVIDES THE 
// SAME IN "AS IS" CONDITION WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS
// OR IMPLIED, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF 
// MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK 
// ARISING OUT OF USE OR PERFORMANCE OF THE SOFTWARE AND DOCUMENTATION 
// REMAINS WITH YOU. 
//
// CONTACT INFORMATION:
// support@morovia.com
// http://www.morovia.com
////////////////////////////////////////////////////////////// 

using System;
using System.Runtime.InteropServices;
using System.Text;
using System.Windows.Forms;

// Programmer's Note
// Class BarcodeDLLImport contains all exports from our Barcode DLL.
// The member functions are just a thin wrapper around the C function exports
// So you can easily find the fucntion you want. You can use this class
// or you can derive your own class with more OOP philosophy. 

sealed public class BarcodeDLLImport
{
	[DllImport("MrvBarDLL.dll")]
	static extern int CreateBarcodeObject(string strLicenseTo, string strRegCode);
	[DllImport("MrvBarDLL.dll")]
	static extern Boolean IsBarcodeObjectDemo(int handle);
	[DllImport("MrvBarDLL.dll")]
	static extern void DestroyBarcodeObject(int handle);
	[DllImport("MrvBarDLL.dll")]
	static extern Boolean GetLastBarcodeErrorMessage(int handle, StringBuilder sbErrorMsg);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_AutoSize(int handle, out Boolean pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_AutoSize(int handle, Boolean val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_BackColor(int handle, out uint pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_BackColor(int handle, uint val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_BorderColor(int handle, out uint pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_BorderColor(int handle, uint pVal);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_BorderStyle(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_BorderStyle(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_BorderWidth(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_BorderWidth(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_Font(int handle, out stdole.IFontDisp pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_Font(int handle, stdole.IFontDisp val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_ForeColor(int handle, out uint pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_ForeColor(int handle, uint pVal);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_Comment(int handle, StringBuilder strValue);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_Comment(int handle, string strValue);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_CommentFont(int handle, out stdole.IFontDisp pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_CommentFont(int handle, stdole.IFontDisp val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_ShowComment(int handle, out Boolean pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_ShowComment(int handle, Boolean val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_CommentOnTop(int handle, out Boolean pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_CommentOnTop(int handle, Boolean val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_CommentAlignment(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_CommentAlignment(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_CommentMarginLeft(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_CommentMarginLeft(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_CommentMarginRight(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_CommentMarginRight(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_CommentMarginTop(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_CommentMarginTop(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_CommentMarginBottom(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_CommentMarginBottom(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_BarHeight(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_BarHeight(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_BearerBars(int handle, out Boolean pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_BearerBars(int handle, Boolean val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_Measurement(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_Measurement(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_Message(int handle, StringBuilder strValue);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_Message(int handle, string strValue);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_NarrowBarWidth(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_NarrowBarWidth(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_NarrowToWideRatio(int handle, out double pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_NarrowToWideRatio(int handle, double val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_Symbology(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_Symbology(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_QuietZones(int handle, out Boolean pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_QuietZones(int handle, Boolean val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_Code39OptionalCheckDigit(int handle, out Boolean pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_Code39OptionalCheckDigit(int handle, Boolean val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_I2of5OptionalCheckDigit(int handle, out Boolean pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_I2of5OptionalCheckDigit(int handle, Boolean val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_Code25OptionalCheckDigit(int handle, out Boolean pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_Code25OptionalCheckDigit(int handle, Boolean val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_UccEanOptionalCheckDigit(int handle, out Boolean pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_UccEanOptionalCheckDigit(int handle, Boolean val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_ShowHRText(int handle, out Boolean pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_ShowHRText(int handle, Boolean val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_TexAlignment(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_TexAlignment(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_Code39StartStopChars(int handle, out Boolean pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_Code39StartStopChars(int handle, Boolean val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_TextOnTop(int handle, out Boolean pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_TextOnTop(int handle, Boolean val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_ShowCheckDigit(int handle, out Boolean pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_ShowCheckDigit(int handle, Boolean val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_SymbolMarginBottom(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_SymbolMarginBottom(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_SymbolMarginLeft(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_SymbolMarginLeft(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_SymbolMarginRight(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_SymbolMarginRight(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_SymbolMarginTop(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_SymbolMarginTop(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_AutoLabelSize(int handle, out Boolean pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_AutoLabelSize(int handle, Boolean val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_LabelHeight(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_LabelHeight(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_LabelWidth(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_LabelWidth(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_Rotation(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_Rotation(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_ZoomRatio(int handle, out double pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_ZoomRatio(int handle, double val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_RasterImageResolution(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_RasterImageResolution(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_DataMatrixTargetSizeID(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_DataMatrixTargetSizeID(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_DataMatrixModuleSize(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_DataMatrixModuleSize(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_PDFAspectRatio(int handle, out double pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_PDFAspectRatio(int handle, double val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_PDFMaxCols(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_PDFMaxCols(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_PDFMaxRows(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_PDFMaxRows(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_PDFModuleHeight(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_PDFModuleHeight(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_PDFModuleWidth(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_PDFModuleWidth(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_PDFSecurityLevel(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_PDFSecurityLevel(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_PDFTruncatedSymbol(int handle, out Boolean pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_PDFTruncatedSymbol(int handle, Boolean val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_MaxicodeClass(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_MaxicodeClass(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_MaxicodeMode(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_MaxicodeMode(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_MaxicodeCountryCode(int handle, out int pVal);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_MaxicodeCountryCode(int handle, int val);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_MaxicodeZipCode(int handle, StringBuilder strValue);
	[DllImport("MrvBarDLL.dll")]
	static extern int put_MaxicodeZipCode(int handle, string strValue);

	[DllImport("MrvBarDLL.dll")]
	static extern int get_Picture(int handle, out stdole.IPictureDisp pVal);

	[DllImport("MrvBarDLL.dll")]
	static extern int mbxAbout(int handle);
	[DllImport("MrvBarDLL.dll")]
	static extern int mbxExportImage(int handle, string strFileName, int imageFormat);
	[DllImport("MrvBarDLL.dll")]
	static extern int mbxLoad(int handle, string strFileName, int persistFormat);
	[DllImport("MrvBarDLL.dll")]
	static extern int mbxSave(int handle, string strFileName, int persistFormat);

	private int _barcode_handle;

	public BarcodeDLLImport()
	{
		_barcode_handle = CreateBarcodeObject("put your license to here",
			"put your registration code here");
	}

	~BarcodeDLLImport()
	{
		DestroyBarcodeObject(_barcode_handle);
	}

	public void About() 
	{
		mbxAbout(_barcode_handle);
	}

	private void ProcessException(int hr)
	{
		if ( hr < 0 )
		{
			//Note: You can not pass an empty buffer, otherwise the program will overflow.
			StringBuilder sb = new StringBuilder(1024);
			if ( GetLastBarcodeErrorMessage(_barcode_handle, sb) )
			{
				throw new COMException(sb.ToString(), hr);
			}
			else
				throw new COMException("unspecified error", hr);
		}
	}

	public Boolean AutoLabelSize
	{
		get
		{
			Boolean val;
			int hr = get_AutoLabelSize(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_AutoLabelSize(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public Boolean AutoSize
	{
		get 
		{
			Boolean val;
			int hr = get_AutoSize(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_AutoSize(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public uint BackColor
	{
		get
		{
			uint color;
			int hr = get_BackColor(_barcode_handle, out color);
			ProcessException(hr);
			return color;
		}
		set
		{
			int hr = put_BackColor(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int BarHeight
	{
		get
		{
			int val;
			int hr = get_BarHeight(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_BarHeight(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public Boolean BearerBars
	{
		get
		{
			Boolean val;
			int hr = get_BearerBars(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_BearerBars(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public uint BorderColor
	{
		get
		{
			uint val;
			int hr = get_BorderColor(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_BorderColor(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int BorderStyle
	{
		get
		{
			int val;
			int hr = get_BorderStyle(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_BorderStyle(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int BorderWidth
	{
		get
		{
			int val;
			int hr = get_BorderWidth(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_BorderWidth(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public Boolean Code25OptionalCheckDigit
	{
		get
		{
			Boolean val;
			int hr = get_Code25OptionalCheckDigit(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_Code25OptionalCheckDigit(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public Boolean Code39OptionalCheckDigit
	{
		get
		{
			Boolean val;
			int hr = get_Code39OptionalCheckDigit(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_Code39OptionalCheckDigit(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public Boolean Codd39StartStopChars
	{
		get
		{
			Boolean val;
			int hr = get_Code39StartStopChars(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_Code39StartStopChars(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public string Comment
	{
		get
		{
			StringBuilder sb = new StringBuilder(1024);
			int hr = get_Comment(_barcode_handle, sb);
			ProcessException(hr);
			return sb.ToString();
		}
		set
		{
			int hr = put_Comment(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int CommentAlignment
	{
		get
		{
			int val;
			int hr = get_CommentAlignment(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_CommentAlignment(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public stdole.IFontDisp CommentFont
	{
		get
		{
			stdole.IFontDisp val;
			int hr = get_CommentFont(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_CommentFont(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int CommentMarginBottom
	{
		get
		{
			int val;
			int hr = get_CommentMarginBottom(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_CommentMarginBottom(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int CommentMarginLeft
	{
		get
		{
			int val;
			int hr = get_CommentMarginLeft(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_CommentMarginLeft(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int CommentMarginRight
	{
		get
		{
			int val;
			int hr = get_CommentMarginRight(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_CommentMarginRight(_barcode_handle, value);
			ProcessException(hr);
		}
	}
	
	public int CommentMarginTop
	{
		get
		{
			int val;
			int hr = get_CommentMarginTop(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_CommentMarginTop(_barcode_handle, value);
			ProcessException(hr);
		}
	}	

	public Boolean CommentOnTop
	{
		get
		{
			Boolean val;
			int hr = get_CommentOnTop(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_CommentOnTop(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public stdole.IFontDisp Font
	{
		get
		{
			stdole.IFontDisp val;
			int hr = get_Font(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_Font(_barcode_handle, value);
			ProcessException(hr);
		}
	}	

	public uint ForeColor
	{
		get
		{
			uint color;
			int hr = get_ForeColor(_barcode_handle, out color);
			ProcessException(hr);
			return color;
		}
		set
		{
			int hr = put_ForeColor(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public Boolean I2of5OptionalCheckDigit
	{
		get
		{
			Boolean val;
			int hr = get_I2of5OptionalCheckDigit(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_I2of5OptionalCheckDigit(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int LabelHeight
	{
		get
		{
			int val;
			int hr = get_LabelHeight(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_LabelHeight(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int LabelWidth
	{
		get
		{
			int val;
			int hr = get_LabelWidth(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_LabelWidth(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int Measurement
	{
		get
		{
			int val;
			int hr = get_Measurement(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_Measurement(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public string message
	{
		get
		{
			StringBuilder sb = new StringBuilder(1024);
			int hr = get_Message(_barcode_handle, sb);
			ProcessException(hr);
			return sb.ToString();
		}
		set
		{
			int hr = put_Message(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int NarrowBarWidth
	{
		get
		{
			int val;
			int hr = get_NarrowBarWidth(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_NarrowBarWidth(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public double NarrowToWideRatio
	{
		get
		{
			double ratio;
			int hr = get_NarrowToWideRatio(_barcode_handle, out ratio);
			ProcessException(hr);
			return ratio;
		}
		set
		{
			int hr = put_NarrowToWideRatio(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public stdole.IPictureDisp Picture
	{
		get
		{
			stdole.IPictureDisp val;
			int hr = get_Picture(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
	}

	public Boolean QuietZones
	{
		get
		{
			Boolean val;
			int hr = get_QuietZones(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_QuietZones(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int RasterImageResolution
	{
		get
		{
			int val;
			int hr = get_RasterImageResolution(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_RasterImageResolution(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int Rotation
	{
		get
		{
			int val;
			int hr = get_Rotation(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_Rotation(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public Boolean ShowCheckDigit
	{
		get
		{
			Boolean val;
			int hr = get_ShowCheckDigit(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_ShowCheckDigit(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public Boolean ShowComment
	{
		get
		{
			Boolean val;
			int hr = get_ShowComment(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_ShowComment(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public Boolean ShowHRText
	{
		get
		{
			Boolean val;
			int  hr = get_ShowHRText(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_ShowHRText(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int SymbolMarginBottom
	{
		get
		{
			int val;
			int hr = get_SymbolMarginBottom(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_SymbolMarginBottom(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int SymbolMarginLeft
	{
		get
		{
			int val;
			int hr = get_SymbolMarginLeft(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_SymbolMarginLeft(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int SymbolMarginRight
	{
		get
		{
			int val;
			int hr = get_SymbolMarginRight(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_SymbolMarginRight(_barcode_handle, value);
			ProcessException(hr);
		}
	}
	
	public int SymbolMarginTop
	{
		get
		{
			int val;
			int hr = get_SymbolMarginTop(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_SymbolMarginTop(_barcode_handle, value);
			ProcessException(hr);
		}
	}	

	public int Symbology
	{
		get
		{
			int val;
			int hr = get_Symbology(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_Symbology(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public int TexAlignment
	{
		get
		{
			int val;
			int hr = get_TexAlignment(_barcode_handle, out val);
			ProcessException(hr);
			return val;											
		}
		set
		{
			int hr = put_TexAlignment(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public Boolean TextOnTop
	{
		get
		{
			Boolean val;
			int hr = get_TextOnTop(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_TextOnTop(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public Boolean UccEanOptionalCheckDigit
	{
		get
		{
			Boolean val;
			int hr = get_UccEanOptionalCheckDigit(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_UccEanOptionalCheckDigit(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public double ZoomRatio
	{
		get
		{
			double val;
			int hr = get_ZoomRatio(_barcode_handle, out val);
			ProcessException(hr);
			return val;
		}
		set
		{
			int hr = put_ZoomRatio(_barcode_handle, value);
			ProcessException(hr);
		}
	}

	public void Load(string strFileName, int persistFormat)
	{
		int hr = mbxLoad(_barcode_handle, strFileName, persistFormat);
		ProcessException(hr);
	}

	public void Save(string strFileName, int persistFormat)
	{
		int hr = mbxSave(_barcode_handle, strFileName, persistFormat);
		ProcessException(hr);
	}

	public void ExportImage(string strFileName, int imageFormat)
	{
		int hr = mbxExportImage(_barcode_handle, strFileName, imageFormat);
		ProcessException(hr);
	}
}

// Programmer's note: AxHost.GetPictureFromIPictureDisp contains a bug. Use GetPictureFromIPicture instead.
// same input and output.
sealed public class ConvertImage : System.Windows.Forms.AxHost
{
	private ConvertImage()
		: base("{63109182-966B-4e3c-A8B2-8BC4A88D221C}")
	{
	}
	public static System.Drawing.Image Convert(object image)
	{
		return (System.Drawing.Image)System.Windows.Forms.AxHost.GetPictureFromIPicture(image);
	}
}